@@ -65,7 +65,6 @@
 #include "gnome-icon-entry.h"
 #include "libgnomeui-access.h"
 #include <sys/stat.h>
-#include <unistd.h>
 #include <string.h>
 
 #include <glib/gstdio.h>
@@ -343,7 +342,7 @@ update_icon (GnomeIconEntry *ientry)
 	}
 	scaled = gdk_pixbuf_scale_simple
 		(pixbuf, w, h, GDK_INTERP_BILINEAR);
-        g_object_unref (G_OBJECT (pixbuf));
+        g_object_unref (pixbuf);
 
 	if (GTK_IS_IMAGE (child)) {
                 gtk_image_set_from_pixbuf (GTK_IMAGE (child), scaled);
@@ -362,7 +361,7 @@ update_icon (GnomeIconEntry *ientry)
 					     GDK_ACTION_COPY);
 		}
 	}
-	g_object_unref (G_OBJECT (scaled));
+	g_object_unref (scaled);
 #if 0
 	gtk_drag_source_set (ientry->_priv->pickbutton,
 			     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
@@ -375,6 +374,7 @@ static void
 entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 {
 	GnomeIconEntryPrivate *priv;
+	GnomeIconSelection    *sel;
 	struct stat buf;
 	const gchar *filename;
 
@@ -383,18 +383,21 @@ entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 	g_return_if_fail (ientry != NULL);
 	g_return_if_fail (GNOME_IS_ICON_ENTRY (ientry));
 
-	priv = ientry->_priv;
-
 	filename = gtk_entry_get_text (GTK_ENTRY (widget));
 
 	if (!filename)
 		return;
 
+	priv = ientry->_priv;
+
 	g_stat (filename, &buf);
 	if (S_ISDIR (buf.st_mode)) {
-		gnome_icon_selection_clear (GNOME_ICON_SELECTION (priv->icon_sel), TRUE);
-		gnome_icon_selection_add_directory (GNOME_ICON_SELECTION (priv->icon_sel), filename);
-		gnome_icon_selection_show_icons (GNOME_ICON_SELECTION (priv->icon_sel));
+		sel  = GNOME_ICON_SELECTION (priv->icon_sel);
+		if (sel) {
+			gnome_icon_selection_clear (sel, TRUE);
+			gnome_icon_selection_add_directory (sel, filename);
+			gnome_icon_selection_show_icons (sel);
+		}
 	} else {
 		/* We pretend like ok has been called */
 		g_free (priv->picked_file);
@@ -405,6 +408,7 @@ entry_activated(GtkWidget *widget, GnomeIconEntry *ientry)
 	}
 }
 
+#if 0
 static void
 setup_preview(GtkWidget *widget)
 {
@@ -454,13 +458,14 @@ setup_preview(GtkWidget *widget)
 	}
 
 	scaled = gdk_pixbuf_scale_simple (pixbuf, w, h, GDK_INTERP_BILINEAR);
-        g_object_unref (G_OBJECT (pixbuf));
+        g_object_unref (pixbuf);
 	pp = gtk_image_new_from_pixbuf (scaled);
-        g_object_unref (G_OBJECT (scaled));
+        g_object_unref (scaled);
 
 	gtk_widget_show(pp);
 	gtk_container_add(GTK_CONTAINER(frame),pp);
 }
+#endif
 
 static void
 ientry_destroy (GtkObject *object)
@@ -513,13 +518,22 @@ ientry_finalize (GObject *object)
 	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
+static void
+entry_changed(GtkEntry *entry)
+{
+	if (g_file_test(gtk_entry_get_text(entry), G_FILE_TEST_IS_DIR))
+		gtk_widget_activate(GTK_WIDGET(entry));
+}
+
 static void
 browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 {
-	GtkWidget *w;
 	GtkFileChooser *fc;
+#if 0
+	GtkWidget *w;
 	GClosure *closure;
 	gchar *path;
+#endif
 
 	g_return_if_fail (fentry != NULL);
 	g_return_if_fail (GNOME_IS_FILE_ENTRY (fentry));
@@ -533,6 +547,7 @@ browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 
 	g_return_if_fail (gtk_file_chooser_get_preview_widget (fc) == NULL);
 
+#if 0
 	w = gtk_frame_new("");
 	gtk_frame_set_shadow_type (GTK_FRAME (w), GTK_SHADOW_NONE);
 
@@ -549,6 +564,7 @@ browse_clicked(GnomeFileEntry *fentry, GnomeIconEntry *ientry)
 		setup_preview (GTK_WIDGET(fc));
 
 	g_free (path);
+#endif
 }
 
 static void
@@ -1037,6 +1053,8 @@ gnome_icon_entry_instance_init (GnomeIconEntry *ientry)
 	g_free(p);
 
 	w = gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(ientry->_priv->fentry));
+	g_signal_connect_after (w, "changed",
+				G_CALLBACK (entry_changed), ientry);
 
 	closure = g_cclosure_new (G_CALLBACK (entry_activated), ientry, NULL);
 	g_object_watch_closure (G_OBJECT (ientry), closure);
