@@ -76,6 +76,7 @@
 #include <gtk/gtkcheckmenuitem.h>
 #include <gtk/gtkmessagedialog.h>
 #include <gtk/gtkaboutdialog.h>
+#include <gtk/gtklinkbutton.h>
 
 /*****************************************************************************
  * libgnomeui
@@ -237,7 +238,8 @@ show_url (GtkWidget *parent,
 	GdkScreen *screen;
 	GError *error = NULL;
 
-	screen = gtk_widget_get_screen (parent);
+	if (parent != NULL)
+		screen = gtk_widget_get_screen (parent);
 
 	if (!gnome_url_show_on_screen (url, screen, &error))
 	{
@@ -329,7 +331,7 @@ libgnomeui_set_property (GObject *object, guint param_id,
         priv = g_object_get_qdata(G_OBJECT(program), quark_gnome_program_private_libgnomeui);
 
 	if (param_id == cdata->default_icon_id)
-		priv->default_icon = g_strdup (g_value_get_string (value));
+		priv->default_icon = g_value_dup_string (value);
 	else if (param_id == cdata->crash_dialog_id)
 		priv->show_crash_dialog = g_value_get_boolean (value) != FALSE;
 	else if (param_id == cdata->display_id)
